//
// Copyright (c) 2012, MindFusion LLC - Bulgaria.
//

using System;
using System.Collections.Generic;
using System.Drawing;
using System.Windows.Forms;

using LinearGradientBrush = MindFusion.Drawing.LinearGradientBrush;


namespace MindFusion.Diagramming.WinForms.Samples.CS.Magnifier
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();

			useCustomMagnifier = false;
			diagramView.ModifierKeyActions.Alt = ModifierKeyAction.None;
			diagramView.RightButtonActions = MouseButtonActions.Cancel;
            diagram.ShapeNodeStyle.Brush = new LinearGradientBrush(Color.FromArgb(224, 233, 233), Color.FromArgb(0, 52, 102));
            diagram.ShapeNodeStyle.Stroke = new MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102));
            diagram.DiagramLinkStyle.Stroke = new MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102));
            diagram.DiagramLinkStyle.HeadStroke = new MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102));
            diagram.DiagramLinkStyle.Brush = new MindFusion.Drawing.SolidBrush(Color.FromArgb(102, 154, 204));
			diagram.LinkHeadShape = MindFusion.Diagramming.ArrowHeads.Triangle;
		}

		private void radioNever_CheckedChanged(object sender, EventArgs e)
		{
			diagramView.MagnifierEnabled = false;
			diagramView.ModifierKeyActions.Alt = ModifierKeyAction.None;
			diagramView.RightButtonActions = MouseButtonActions.Cancel;
			diagramView.Invalidate();
		}

		private void radioOnRightClick_CheckedChanged(object sender, EventArgs e)
		{
			diagramView.MagnifierEnabled = false;
			diagramView.ModifierKeyActions.Alt = ModifierKeyAction.None;
			diagramView.RightButtonActions = MouseButtonActions.Magnify;
			diagramView.Invalidate();
		}

		private void radioOnAlt_CheckedChanged(object sender, EventArgs e)
		{
			diagramView.MagnifierEnabled = false;
			diagramView.ModifierKeyActions.Alt = ModifierKeyAction.Magnify;
			diagramView.RightButtonActions = MouseButtonActions.Cancel;
			diagramView.Invalidate();
		}

		private void radioAlways_CheckedChanged(object sender, EventArgs e)
		{
			diagramView.MagnifierEnabled = true;
			diagramView.ModifierKeyActions.Alt = ModifierKeyAction.None;
			diagramView.RightButtonActions = MouseButtonActions.Cancel;
			diagramView.Invalidate();
		}

		private void radioDefault_CheckedChanged(object sender, EventArgs e)
		{
			useCustomMagnifier = false;
			diagramView.MagnifierFrameThickness = 3;
			diagramView.MagnifierShading = true;
			if (shapeListBox.SelectedItem != null)
				diagramView.MagnifierShape = (shapeListBox.SelectedItem as ShapeNode).Shape;
			diagramView.Invalidate();
		}

		private void radioCustom_CheckedChanged(object sender, EventArgs e)
		{
			useCustomMagnifier = true;
			diagramView.MagnifierFrameThickness = 0;
			diagramView.MagnifierShading = false;
			diagramView.MagnifierShape = Shapes.Ellipse;
			diagramView.Invalidate();
		}

		private void trackBarSize_Scroll(object sender, EventArgs e)
		{
			diagramView.MagnifierWidth = trackBarSize.Value * 2;
			diagramView.MagnifierHeight = trackBarSize.Value * 2;
		}

		private void trackBarZoom_Scroll(object sender, EventArgs e)
		{
			diagramView.MagnifierFactor = trackBarZoom.Value;
		}

		private void diagramView_DrawMagnifier(object sender, DrawEventArgs e)
		{
			if (useCustomMagnifier)
			{
				RectangleF bounds = e.Bounds;
				bounds.Inflate(bounds.Width * 0.05f, bounds.Height * 0.05f);
				e.Graphics.DrawImage(Properties.Resources.Magnifier, bounds);
			}
		}

		private void shapeListBox_SelectedIndexChanged(object sender, EventArgs e)
		{
			if (!useCustomMagnifier && shapeListBox.SelectedItem != null)
				diagramView.MagnifierShape = (shapeListBox.SelectedItem as ShapeNode).Shape;
		}


		private bool useCustomMagnifier;
	}
}
